from django.conf import settings

import json
import os
import re

from django.utils.translation import get_language

def get_translation(key, language=None, values=None):
    _language = language or get_language() or 'en'
    filepath = os.path.join(settings.DJANGO_I18NIZE_CONFIG.get('destination_dir'), u'{}.{}'.format(_language, 'json'))

    with open(filepath) as data_file:
        data = json.load(data_file)
        value = data.get(key) or key

        key_variables = re.findall(r'\{\{[^}]*}}', value)

        if values:
            for variable in key_variables:
                key = variable.replace('{', '').replace('}', '').strip()
                variable_value = values.get(key)

                if variable_value:
                    value = value.replace(variable, variable_value)

        return value


from django.conf import settings
from importlib import import_module
import os

BASE_DIR = os.path.dirname(os.path.dirname(__file__))

# Default configuration
DEFAULT_CONFIG = {
    "project_id": None,
    "live": False,
    'destination_dir': os.path.realpath(os.path.join(BASE_DIR, 'staticfiles', 'locale'))
}

# Update CONFIG with user added configuration
CONFIG = DEFAULT_CONFIG.copy()
if hasattr(settings, 'DJANGO_I18NIZE_CONFIG'):
    for key, value in settings.DJANGO_I18NIZE_CONFIG.iteritems():
        CONFIG[key] = value
else:
    raise AttributeError('django_i18nize requires DJANGO_I18NIZE_CONFIG inside of you project settings file. Please read the README.md on github for more details.')

# Add DJANGO_I18NIZE_CONFIG to root settings
def patch_settings():
    setattr(settings, 'DJANGO_I18NIZE_CONFIG', CONFIG)


def patch_all():
    patch_settings()


from __future__ import absolute_import, unicode_literals
from django.apps import AppConfig
from django.utils.translation import ugettext_lazy as _
from django_i18nize import settings as plugin_settings


class i18nizeConfig(AppConfig):
    name = 'django_i18nize'
    verbose_name = _("Django i18nize")

    def ready(self):
        plugin_settings.patch_all()


from django import template
register = template.Library()

from django_i18nize.utils import get_translation

@register.simple_tag
def i18n_switch(key, language=None, values=None):
    return get_translation(key, language, values)


# -*- coding: utf-8 -*-
import os
from django.core.management.base import NoArgsCommand
from django.db.models import signals
from django.db.utils import IntegrityError

from i18nize.client import Client
from django.conf import settings

import os


class Command(NoArgsCommand):

    def handle(self, *args, **options):
        client = Client(**settings.DJANGO_I18NIZE_CONFIG)
        client.get_all_locales()


# -*- coding: utf-8 -*-
from distutils.core import setup
from setuptools import find_packages

setup(
    name='django_i18nize',
    version='0.0.1',
    author=u'Mohammed Hammoud',
    author_email='mohammed@iktw.se',
    packages=find_packages(),
    url='https://github.com/iktw/i18nize-django',
    license='MIT licence, see LICENCE.txt',
    description='Django i18nize extends the i18nize python client. Template tag for rendering translation and Management command for fetching  translations is added.',
    long_description=open('README.md').read(),
    zip_safe=False,
    include_package_data=True,
    install_requires=[
        'i18nize',
    ],
)